from redis import Redis


class Redisary(object):
    def __init__(self, host: str = 'localhost', port: int = 6379, db: int = 0, encoding: str = 'utf-8',
                 expire: int = None):
        self._redis = Redis(host=host, port=port, db=db, encoding=encoding)
        self._expire = expire
        self._encoding = encoding

    def __setitem__(self, key: any, value: any) -> bool:
        if self._expire:
            return self._redis.setex(key, self._expire, value)
        return self._redis.set(key, value)

    def __getitem__(self, key: any) -> str:
        value = self._redis.get(key)

        if value:
            if self._expire:
                self._redis.expire(key, self._expire)
            return value.decode(self._encoding)

        raise KeyError(key)

    def __contains__(self, key: any) -> bool:
        return self._redis.exists(key)



import re

from setuptools import setup

with open('redisary/__init__.py') as f:
    version = re.search(r'([0-9]+(\.dev|\.|)){3}', f.read()).group(0)

with open('README.md') as f:
    readme = f.read()

name = 'redisary'
owner = 'xurvan'

setup(
    name=name,
    version=version,
    license='apache-2.0',
    description='Redis as dictionary',
    long_description=readme,
    long_description_content_type='text/markdown',
    author='Xurvan',
    url=f'https://github.com/{owner}/{name}',
    download_url=f'https://github.com/{owner}/{name}/releases/tag/v{version}',
    project_urls={
        'Code': f'https://github.com/{owner}/{name}',
        'Issue tracker': f'https://github.com/{owner}/{name}/issues',
    },
    packages=[name],
    install_requires=['redis'],
    python_requires='>=3.6',
    zip_safe=False,
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python :: 3'
    ],
)
